[Bf-blender-cvs] [5159ba6b333] master: Fix (harmless) PCRE not found warning when configuring CMake on Linux

Brecht Van Lommel noreply at git.blender.org
Thu Apr 2 17:09:33 CEST 2020


Commit: 5159ba6b333b27b247ffe0b950fa40c1dd7d2654
Author: Brecht Van Lommel
Date:   Fri Mar 27 14:24:52 2020 +0100
Branches: master
https://developer.blender.org/rB5159ba6b333b27b247ffe0b950fa40c1dd7d2654

Fix (harmless) PCRE not found warning when configuring CMake on Linux

Differential Revision: https://developer.blender.org/D7309

===================================================================

M	build_files/buildbot/config/blender_linux.cmake
M	build_files/cmake/platform/platform_apple.cmake
M	build_files/cmake/platform/platform_unix.cmake

===================================================================

diff --git a/build_files/buildbot/config/blender_linux.cmake b/build_files/buildbot/config/blender_linux.cmake
index 2db95c85fc2..29004654807 100644
--- a/build_files/buildbot/config/blender_linux.cmake
+++ b/build_files/buildbot/config/blender_linux.cmake
@@ -24,11 +24,5 @@ set(LIBDIR "${CMAKE_CURRENT_LIST_DIR}/../../../../lib/${LIBDIR_NAME}" CACHE STRI
 
 # Platform specific configuration, to ensure static linking against everything.
 
-# We need to link OpenCOLLADA against PCRE library. Even though it is not installed
-# on /usr, we do not really care -- all we care is PCRE_FOUND be TRUE and its
-# library pointing to a valid one.
-set(PCRE_INCLUDE_DIR          "/usr/include"                        CACHE STRING "" FORCE)
-set(PCRE_LIBRARY              "${LIBDIR}/opencollada/lib/libpcre.a" CACHE STRING "" FORCE)
-
 # Additional linking libraries
 set(CMAKE_EXE_LINKER_FLAGS   "-lrt -static-libstdc++ -no-pie"  CACHE STRING "" FORCE)
diff --git a/build_files/cmake/platform/platform_unix.cmake b/build_files/cmake/platform/platform_unix.cmake
index c034e7028af..3f73916daf3 100644
--- a/build_files/cmake/platform/platform_unix.cmake
+++ b/build_files/cmake/platform/platform_unix.cmake
@@ -195,8 +195,14 @@ endif()
 if(WITH_OPENCOLLADA)
   find_package_wrapper(OpenCOLLADA)
   if(OPENCOLLADA_FOUND)
-    find_package_wrapper(XML2)
-    find_package_wrapper(PCRE)
+    if(WITH_STATIC_LIBS)
+      # PCRE and XML2 are bundled with OpenCollada.
+      set(PCRE_LIBRARIES pcre)
+      set(XML2_LIBRARIES xml2)
+    else()
+      find_package_wrapper(XML2)
+      find_package_wrapper(PCRE)
+    endif()
   else()
     set(WITH_OPENCOLLADA OFF)
   endif()



More information about the Bf-blender-cvs mailing list
diff --git a/build_files/cmake/platform/platform_apple.cmake b/build_files/cmake/platform/platform_apple.cmake
index 620a078f412..f5f8c209d9d 100644
--- a/build_files/cmake/platform/platform_apple.cmake
+++ b/build_files/cmake/platform/platform_apple.cmake
@@ -222,12 +222,10 @@ if(WITH_OPENCOLLADA)
     -lMathMLSolver
     -lGeneratedSaxParser
     -lbuffer -lftoa -lUTF
-    ${OPENCOLLADA_LIBPATH}/libxml2.a
   )
   # PCRE is bundled with openCollada
   # set(PCRE ${LIBDIR}/pcre)
   # set(PCRE_LIBPATH ${PCRE}/lib)
   set(PCRE_LIBRARIES pcre)
+  set(XML2_LIBRARIES xml2)
 endif()
 
 if(WITH_SDL)
@@ -222,12 +222,10 @@ if(WITH_OPENCOLLADA)
   )
-  # PCRE is bundled with openCollada
-  # set(PCRE ${LIBDIR}/pcre)
-  # set(PCRE_LIBPATH ${PCRE}/lib)
+  # PCRE and XML2 are bundled with OpenCollada.
   set(PCRE_LIBRARIES pcre)